Struct MultiWakerRegistration
Source pub struct MultiWakerRegistration<const N: usize> { }
Utility struct to register and wake multiple wakers.
Queue of wakers with a maximum length of N.
Intended for waking multiple tasks.
Create a new empty instance
Register a waker.
If the buffer is full, wakes all the wakers, clears its buffer and registers the waker.
Wake all registered wakers. This clears the buffer
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.