pub struct WakerRegistration { /* private fields */ }Expand description
Utility struct to register and wake a waker. If a waker is registered, registering another waker will replace the previous one. The previous waker will be woken in this case, giving it a chance to reregister itself. Although it is possible to wake multiple tasks this way, this will cause them to wake each other in a loop registering themselves.
Implementations